"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Errors = /** @class */ (function () {
    /**
     * Create a new Errors instance.
     */
    function Errors() {
        this.errors = {};
    }
    /**
     * Determine if an errors exists for the given field.
     */
    Errors.prototype.has = function (field) {
        return typeof this.errors[field] !== 'undefined';
    };
    /**
     * Determine if we have any errors.
     */
    Errors.prototype.any = function () {
        return Object.keys(this.errors).length > 0;
    };
    /**
     * Retrieve the error message for a field.
     */
    Errors.prototype.get = function (field) {
        return this.has(field) ? this.errors[field][0] : null;
    };
    /**
     * Retrieve all error messages.
     */
    Errors.prototype.getAll = function () {
        var _this = this;
        return this.any() ? Object.keys(this.errors).map(function (field) { return _this.get(field); }) : [];
    };
    /**
     * Record the new errors.
     */
    Errors.prototype.record = function (errors) {
        var _this = this;
        this.clear();
        Object.keys(errors).forEach(function (field) {
            _this.errors[field] = errors[field];
        });
    };
    /**
     * Clear one or all error fields.
     */
    Errors.prototype.clear = function (field) {
        if (field === void 0) { field = null; }
        if (field) {
            delete this.errors[field];
            return;
        }
        this.errors = {};
    };
    return Errors;
}());
exports.default = Errors;
//# sourceMappingURL=Errors.js.map