"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormMethods = void 0;
var index_1 = __importDefault(require("lodash.isobject/index"));
var Errors_1 = __importDefault(require("./Errors"));
var Request_1 = __importDefault(require("./Request"));
var FormMethods;
(function (FormMethods) {
    FormMethods["POST"] = "post";
    FormMethods["PATCH"] = "patch";
    FormMethods["PUT"] = "put";
})(FormMethods = exports.FormMethods || (exports.FormMethods = {}));
var Form = /** @class */ (function () {
    /**
     * Create a new Form instance.
     */
    function Form(data, config) {
        var _this = this;
        if (config === void 0) { config = {}; }
        var _a;
        this.config = __assign({ resetAfterSend: true, removeNullValues: true, method: FormMethods.POST }, config);
        Object.keys(data).forEach(function (key) {
            _this[key] = data[key];
        });
        this.originalData = __assign({}, data);
        this.errors = new Errors_1.default();
        this.request = (_a = this.config.request) !== null && _a !== void 0 ? _a : Request_1.default.getInstance();
        if (this.config.method !== FormMethods.POST) {
            this.addField('_method', this.config.method);
        }
    }
    /**
     * Add a new field with value to the form.
     */
    Form.prototype.addField = function (field, value) {
        this.originalData[field] = value;
        this[field] = value;
    };
    /**
     * Get FormData object.
     */
    Form.prototype.serialize = function () {
        var _this = this;
        var json = {};
        Object.keys(this.originalData).forEach(function (field) {
            json[field] = _this[field];
        });
        return JSON.stringify(json);
    };
    /**
     * Submit the form.
     */
    Form.prototype.submit = function (url) {
        var _this = this;
        this.errors.clear();
        var data = this.getFormData();
        var config = { headers: { 'Content-Type': 'multipart/form-data' } };
        return new Promise(function (resolve, reject) {
            _this.request.post(url, data, config)
                .then(function (response) {
                if (_this.config.resetAfterSend) {
                    _this.reset();
                }
                return resolve(response.data);
            })
                .catch(function (error) {
                var _a, _b;
                if (typeof ((_a = error.response) === null || _a === void 0 ? void 0 : _a.data.errors) !== 'undefined') {
                    _this.errors.record(error.response.data.errors);
                }
                return reject((_b = error.response) === null || _b === void 0 ? void 0 : _b.data);
            });
        });
    };
    /**
     * Get FormData object.
     */
    Form.prototype.getFormData = function () {
        var _this = this;
        var formData = new FormData();
        Object.keys(this.originalData).forEach(function (field) {
            var value = _this[field];
            if (value === null && _this.config.removeNullValues) {
                return;
            }
            if (typeof value === 'boolean') {
                formData.append(field, Number(value).toString());
            }
            else if (Array.isArray(value)) {
                value.forEach(function (item) {
                    formData.append(field + "[]", item);
                });
            }
            else if (index_1.default(value) && !(value instanceof File)) {
                Object.keys(value).forEach(function (key) {
                    // @ts-ignore
                    formData.append(field + "[" + key + "]", value[key]);
                });
            }
            else {
                formData.append(field, value);
            }
        });
        return formData;
    };
    /**
     * Reset the state of the form to the original state and clears errors.
     */
    Form.prototype.reset = function () {
        var _this = this;
        Object.keys(this.originalData).forEach(function (field) {
            _this[field] = _this.originalData[field];
        });
        this.errors.clear();
    };
    return Form;
}());
exports.default = Form;
//# sourceMappingURL=Form.js.map